# kensu-py
Open source some py integration modules to automate Data and Analytics Observability

[![Join the chat at https://gitter.im/kensuio-oss/kensu-py](https://badges.gitter.im/kensuio-oss/kensu-py.svg)](https://gitter.im/kensuio-oss/kensu-py?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![Live the full adventure and try a Data and Analytics Observability platform](https://img.shields.io/static/v1?label=Platform&message=Try%20Kensu&color=blue)](https://hubs.li/H0M3Jrd0)

## Installation

### From pypi

`pip install kensu`


## Development

### Build

`pip install -r requirements.txt .`

### Run tests

```
pip install -r requirements-test.txt .`
pytest tests/unit/test_sftp.py
python3 -m unittest  -s tests/unit/ test_external_to_pandas.TestExternalToPandas
```

## Data and Analytics Observability platform

Check out [Kensu](https://kensu.io) and the [trial program](https://hubs.li/H0M3Jrd0).
